DLPackTensorRefMut

Struct DLPackTensorRefMut 

pub struct DLPackTensorRefMut<'a> { /* private fields */ }
A mutable reference to a DLPack tensor, with data borrowed from some owner, potentially in another language.

Implementations

Source

impl<'a> DLPackTensorRefMut<'a>

pub unsafe fn from_raw(tensor: DLTensor) -> DLPackTensorRefMut<'a>

Create a DLPackTensorRefMut from a raw DLTensor

Safety

The lifetime of the returned reference should be constrained to the actual lifetime of the DLTensor. The DLTensor should also be mutable, and there should not be any other references (mutable or not) to the same DLTensor.

pub fn as_ref(&self) -> DLPackTensorRef<'_>

Convert this mutable reference to an immutable reference.

pub fn data_ptr<T>(&self) -> Result<*const T, CastError>

Get a pointer to data in this tensor. This pointer can be a device pointer according to DLPackTensorRefMut::device.

pub fn data_ptr_mut<T>(&mut self) -> Result<*mut T, CastError>

Get a mutable pointer to data in this tensor. This pointer can be a device pointer according to DLPackTensorRefMut::device.

pub fn device(&self) -> DLDevice

Get the device where the data of this tensor lives.

pub fn dtype(&self) -> DLDataType

Get the data type of this tensor

pub fn n_dims(&self) -> usize

Get the number of dimensions of this tensor

pub fn shape(&self) -> &[i64]

Get the shape of this tensor

pub fn strides(&self) -> Option<&[i64]>

Get the strides of this tensor, if any

pub fn byte_offset(&self) -> usize

Get the byte offset of this tensor, i.e. how many bytes should be added to DLPackTensorRefMut::data_ptr and DLPackTensorRefMut::data_ptr_mut to get the first element of the tensor.

pub fn as_dltensor(&self) -> &DLTensor

Get a reference to the underlying DLTensor